==> ejc-sealm-api-3.0.0-20220107.080017-19-sources.jar: com.ejianc.business.sealm/vo/YzhsVO.java <==
package com.ejianc.business.sealm.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 印章回收
 * 
 * @author generator
 * 
 */
public class YzhsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String remark; // 备注
    private Integer zt; // 状态，默认0总部在库。1正常发放2外借待归3已销毁
    private String yzbhCode; // 印章编号
    private Long yzlbId; // 印章类别id
    private String yzlbName; // 印章类别名称
    private Long yzjbId; // 印章级别id
    private String yzjbName; // 印章级别名称
    private Long yylxId; // 用印类型id
    private String yylxName; // 用印类型名称
    private String kzzy; // 刻章字样
    private Long ssdwId; // 所属单位id
    private String ssdwName; // 所属单位名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date kzsjTime; // 刻章时间
    private Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date basjTime; // 备案时间
    private String badwName; // 备案单位
    private String scdw; // 生产单位
    private Long hsdwId; // 回收单位id
    private String hsdwName; // 回收单位名称
    private Long hsbgrId; // 回收保管人id
    private String hsbgrName; // 回收保管人名字
    private String bgrName; // 保管人
    private java.lang.Long scdwId; // 生产单位id
    private java.lang.String scdwName; // 生产单位名称

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 经办人ID
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人ID
     */
    @ReferDeserialTransfer
    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人姓名
     */
    public String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人姓名
     */
    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁
     */
    public Integer getZt() {
        return zt;
    }

    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁
     */
    public void setZt(Integer zt) {
        this.zt = zt;
    }
    /**
     * 印章编号
     */
    public String getYzbhCode() {
        return yzbhCode;
    }

    /**
     * 印章编号
     */
    public void setYzbhCode(String yzbhCode) {
        this.yzbhCode = yzbhCode;
    }
    /**
     * 印章类别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    @ReferDeserialTransfer
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    @ReferDeserialTransfer
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    @ReferDeserialTransfer
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    @ReferDeserialTransfer
    public void setSsdwId(Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 刻章时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻章时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位
     */
    public String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位
     */
    public void setBadwName(String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位
     */
    public String getScdw() {
        return scdw;
    }

    /**
     * 生产单位
     */
    public void setScdw(String scdw) {
        this.scdw = scdw;
    }
    /**
     * 回收单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getHsdwId() {
        return hsdwId;
    }

    /**
     * 回收单位id
     */
    @ReferDeserialTransfer
    public void setHsdwId(Long hsdwId) {
        this.hsdwId = hsdwId;
    }
    /**
     * 回收单位名称
     */
    public String getHsdwName() {
        return hsdwName;
    }

    /**
     * 回收单位名称
     */
    public void setHsdwName(String hsdwName) {
        this.hsdwName = hsdwName;
    }
    /**
     * 回收保管人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getHsbgrId() {
        return hsbgrId;
    }

    /**
     * 回收保管人id
     */
    @ReferDeserialTransfer
    public void setHsbgrId(Long hsbgrId) {
        this.hsbgrId = hsbgrId;
    }
    /**
     * 回收保管人名字
     */
    public String getHsbgrName() {
        return hsbgrName;
    }

    /**
     * 回收保管人名字
     */
    public void setHsbgrName(String hsbgrName) {
        this.hsbgrName = hsbgrName;
    }
    /**
     * 保管人
     */
    public String getBgrName() {
        return bgrName;
    }

    /**
     * 保管人
     */
    public void setBgrName(String bgrName) {
        this.bgrName = bgrName;
    }
    /**
     * 生产单位id
     */
    public java.lang.Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(java.lang.Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public java.lang.String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(java.lang.String scdwName) {
        this.scdwName = scdwName;
    }
}

==> ejc-sealm-api-3.0.0-20220113.095416-32-sources.jar: com.ejianc.business.sealm/vo/YzhsVO.java <==
package com.ejianc.business.sealm.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 印章回收
 * 
 * @author generator
 * 
 */
public class YzhsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String remark; // 备注
    private Integer zt; // 状态，默认0总部在库。1正常发放2外借待归3已销毁
    private String yzbhCode; // 印章编号
    private Long yzlbId; // 印章类别id
    private String yzlbName; // 印章类别名称
    private Long yzjbId; // 印章级别id
    private String yzjbName; // 印章级别名称
    private Long yylxId; // 用印类型id
    private String yylxName; // 用印类型名称
    private String kzzy; // 刻章字样
    private Long ssdwId; // 所属单位id
    private String ssdwName; // 所属单位名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date kzsjTime; // 刻章时间
    private Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date basjTime; // 备案时间
    private java.lang.Long badwId; // 备案单位id
    private String badwName; // 备案单位
    private String scdw; // 生产单位
    private Long hsdwId; // 回收单位id
    private String hsdwName; // 回收单位名称
    private Long hsbgrId; // 回收保管人id
    private String hsbgrName; // 回收保管人名字
    private java.lang.Long bgrId; // 保管人id
    private String bgrName; // 保管人
    private java.lang.Long scdwId; // 生产单位id
    private java.lang.String scdwName; // 生产单位名称

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 经办人ID
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人ID
     */
    @ReferDeserialTransfer
    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人姓名
     */
    public String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人姓名
     */
    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁
     */
    public Integer getZt() {
        return zt;
    }

    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁
     */
    public void setZt(Integer zt) {
        this.zt = zt;
    }
    /**
     * 印章编号
     */
    public String getYzbhCode() {
        return yzbhCode;
    }

    /**
     * 印章编号
     */
    public void setYzbhCode(String yzbhCode) {
        this.yzbhCode = yzbhCode;
    }
    /**
     * 印章类别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    @ReferDeserialTransfer
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    @ReferDeserialTransfer
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    @ReferDeserialTransfer
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    @ReferDeserialTransfer
    public void setSsdwId(Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 刻章时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻章时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位id
     */
    public java.lang.Long getBadwId() {
        return badwId;
    }

    /**
     * 备案单位id
     */
    public void setBadwId(java.lang.Long badwId) {
        this.badwId = badwId;
    }
    /**
     * 备案单位
     */
    public String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位
     */
    public void setBadwName(String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位
     */
    public String getScdw() {
        return scdw;
    }

    /**
     * 生产单位
     */
    public void setScdw(String scdw) {
        this.scdw = scdw;
    }
    /**
     * 回收单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getHsdwId() {
        return hsdwId;
    }

    /**
     * 回收单位id
     */
    @ReferDeserialTransfer
    public void setHsdwId(Long hsdwId) {
        this.hsdwId = hsdwId;
    }
    /**
     * 回收单位名称
     */
    public String getHsdwName() {
        return hsdwName;
    }

    /**
     * 回收单位名称
     */
    public void setHsdwName(String hsdwName) {
        this.hsdwName = hsdwName;
    }
    /**
     * 回收保管人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getHsbgrId() {
        return hsbgrId;
    }

    /**
     * 回收保管人id
     */
    @ReferDeserialTransfer
    public void setHsbgrId(Long hsbgrId) {
        this.hsbgrId = hsbgrId;
    }
    /**
     * 回收保管人名字
     */
    public String getHsbgrName() {
        return hsbgrName;
    }

    /**
     * 回收保管人名字
     */
    public void setHsbgrName(String hsbgrName) {
        this.hsbgrName = hsbgrName;
    }
    /**
     * 保管人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public java.lang.Long getBgrId() {
        return bgrId;
    }

    /**
     * 保管人id
     */
    @ReferDeserialTransfer
    public void setBgrId(java.lang.Long bgrId) {
        this.bgrId = bgrId;
    }
    /**
     * 保管人
     */
    public String getBgrName() {
        return bgrName;
    }

    /**
     * 保管人
     */
    public void setBgrName(String bgrName) {
        this.bgrName = bgrName;
    }
    /**
     * 生产单位id
     */
    public java.lang.Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(java.lang.Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public java.lang.String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(java.lang.String scdwName) {
        this.scdwName = scdwName;
    }
}
